==> activity-center-biz-1.2.9.8.transfer-20161118.085627-1-sources.jar: cn/com/duiba/activity/center/biz/service/prize/impl/ActivityPrizeOptionServiceImpl.java <==
/**
 * Project Name:activity-center-biz
 * File Name:ActivityPrizeOptionServiceImpl.java
 * Package Name:cn.com.duiba.activity.center.biz.service.prize.impl
 * Date:2016年7月26日下午4:03:00
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.activity.center.biz.service.prize.impl;

import java.util.List;

import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.com.duiba.activity.center.api.dto.prize.ActivityPrizeOptionDto;
import cn.com.duiba.activity.center.biz.dao.prize.ActivityPrizeOptionDao;
import cn.com.duiba.activity.center.biz.service.prize.ActivityPrizeOptionService;

/**
 * ClassName:ActivityPrizeOptionServiceImpl <br/>
 * Function: TODO ADD FUNCTION. <br/>
 * Reason:	 TODO ADD REASON. <br/>
 * Date:     2016年7月26日 下午4:03:00 <br/>
 * @author   zp
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
@Service
public class ActivityPrizeOptionServiceImpl implements ActivityPrizeOptionService{
    
    @Autowired
    private ActivityPrizeOptionDao activityPrizeOptionDao;

    @Override
    public Long saveOrUpdateOption(ActivityPrizeOptionDto activityPrizeOptionDto) {
        if(null != activityPrizeOptionDto.getId()){
            return activityPrizeOptionDao.update(activityPrizeOptionDto);
        }
        return activityPrizeOptionDao.insert(activityPrizeOptionDto);
    }

    @Override
    public Boolean deleteOption(Long id) {
        return activityPrizeOptionDao.delete(id);
    }

    @Override
    public List<ActivityPrizeOptionDto> queryActivityOptionsByConfigId(Long configId,String activityType) {
        return activityPrizeOptionDao.selectActivityOptionsByConfigId(configId, activityType);
    }
    
    @Override
    public List<ActivityPrizeOptionDto> queryCouponActivityOptionsByIds(List<Long> configIds,String activityType, String prizeType){
    	return activityPrizeOptionDao.selectCouponActivityOptionsByIds(configIds, activityType, prizeType);
    }

    @Override
    public ActivityPrizeOptionDto find(Long id) {
        return activityPrizeOptionDao.find(id);
    }

    @Override
    public List<ActivityPrizeOptionDto> queryActivityOptionsByConfigIds(List<Long> configIds,
                                                                                   String activityType) {
        return activityPrizeOptionDao.selectActivityOptionsByConfigIds(configIds, activityType);
    }

    @Override
    public List<ActivityPrizeOptionDto> queryActivityOptionsByActivityType(String activityType,Integer offset,Integer max) {
        return activityPrizeOptionDao.selectActivityOptionsByActivityType(activityType,offset,max);
    }

    @Override
    public Long queryCountByActivityType(String activityType) {
        return activityPrizeOptionDao.selectCountByActivityType(activityType);
    }

    @Override
    public List<ActivityPrizeOptionDto> queryRandomByActivityType(String activityType, int number, List<Long> ids) {
        if(CollectionUtils.isEmpty(ids)){
            ids = null;
        }
        return activityPrizeOptionDao.selectRandomByActivityType(activityType, number, ids);
    }
    
    

}

==> activity-center-biz-1.2.9.11.transfer-20161118.093154-1-sources.jar: cn/com/duiba/activity/center/biz/service/prize/impl/ActivityPrizeOptionServiceImpl.java <==
/**
 * Project Name:activity-center-biz
 * File Name:ActivityPrizeOptionServiceImpl.java
 * Package Name:cn.com.duiba.activity.center.biz.service.prize.impl
 * Date:2016年7月26日下午4:03:00
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.activity.center.biz.service.prize.impl;

import java.util.List;

import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.com.duiba.activity.center.api.dto.prize.ActivityPrizeOptionDto;
import cn.com.duiba.activity.center.biz.dao.prize.ActivityPrizeOptionDao;
import cn.com.duiba.activity.center.biz.service.prize.ActivityPrizeOptionService;

/**
 * ClassName:ActivityPrizeOptionServiceImpl <br/>
 * Function: TODO ADD FUNCTION. <br/>
 * Reason:	 TODO ADD REASON. <br/>
 * Date:     2016年7月26日 下午4:03:00 <br/>
 * @author   zp
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
@Service
public class ActivityPrizeOptionServiceImpl implements ActivityPrizeOptionService{
    
    @Autowired
    private ActivityPrizeOptionDao activityPrizeOptionDao;

    @Override
    public Long saveOrUpdateOption(ActivityPrizeOptionDto activityPrizeOptionDto) {
        if(null != activityPrizeOptionDto.getId()){
            return activityPrizeOptionDao.update(activityPrizeOptionDto);
        }
        return activityPrizeOptionDao.insert(activityPrizeOptionDto);
    }

    @Override
    public Boolean deleteOption(Long id) {
        return activityPrizeOptionDao.delete(id);
    }

    @Override
    public List<ActivityPrizeOptionDto> queryActivityOptionsByConfigId(Long configId,String activityType) {
        return activityPrizeOptionDao.selectActivityOptionsByConfigId(configId, activityType);
    }
    
    @Override
    public List<ActivityPrizeOptionDto> queryCouponActivityOptionsByIds(List<Long> configIds,String activityType, String prizeType){
    	return activityPrizeOptionDao.selectCouponActivityOptionsByIds(configIds, activityType, prizeType);
    }

    @Override
    public ActivityPrizeOptionDto find(Long id) {
        return activityPrizeOptionDao.find(id);
    }

    @Override
    public List<ActivityPrizeOptionDto> queryActivityOptionsByConfigIds(List<Long> configIds,
                                                                                   String activityType) {
        return activityPrizeOptionDao.selectActivityOptionsByConfigIds(configIds, activityType);
    }

    @Override
    public List<ActivityPrizeOptionDto> queryActivityOptionsByActivityType(String activityType,Integer offset,Integer max) {
        return activityPrizeOptionDao.selectActivityOptionsByActivityType(activityType,offset,max);
    }

    @Override
    public Long queryCountByActivityType(String activityType) {
        return activityPrizeOptionDao.selectCountByActivityType(activityType);
    }

    @Override
    public List<ActivityPrizeOptionDto> queryRandomByActivityType(String activityType, int number, List<Long> ids) {
        if(CollectionUtils.isEmpty(ids)){
            ids = null;
        }
        return activityPrizeOptionDao.selectRandomByActivityType(activityType, number, ids);
    }

    @Override
    public List<ActivityPrizeOptionDto> queryActivityOptionsByConfigIdAndDays(Long configId, String activityType,
                                                                              String otherUse) {
        return activityPrizeOptionDao.selectActivityOptionsByConfigIdAndDays(configId, activityType, otherUse);
    }
}
